Struct Utf16CodeUnitsMetric
pub struct Utf16CodeUnitsMetric(/* private fields */);Trait Implementations
impl Clone for Utf16CodeUnitsMetric
impl Clone for Utf16CodeUnitsMetric
fn clone(&self) -> Utf16CodeUnitsMetric
fn clone(&self) -> Utf16CodeUnitsMetric
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Metric<RopeInfo> for Utf16CodeUnitsMetric
impl Metric<RopeInfo> for Utf16CodeUnitsMetric
fn measure(info: &RopeInfo, _: usize) -> usize
fn measure(info: &RopeInfo, _: usize) -> usize
Return the size of the
NodeInfo::L, as measured by this
metric. Read more
fn is_boundary(s: &String, offset: usize) -> bool
fn is_boundary(s: &String, offset: usize) -> bool
Return whether the offset in base units is a boundary of this metric.
If a boundary is at end of a leaf then this method must return true.
However, a boundary at the beginning of a leaf is optional
(the previous leaf will be queried).
fn to_base_units(s: &String, in_measured_units: usize) -> usize
fn to_base_units(s: &String, in_measured_units: usize) -> usize
Returns the smallest offset, in base units, for an offset in measured units. Read more
fn from_base_units(s: &String, in_base_units: usize) -> usize
fn from_base_units(s: &String, in_base_units: usize) -> usize
Returns the smallest offset in measured units corresponding to an offset in base units. Read more
fn prev(s: &String, offset: usize) -> Option<usize>
fn prev(s: &String, offset: usize) -> Option<usize>
Returns the index of the boundary directly preceding offset,
or None if no such boundary exists. Input and result are in base units.
fn next(s: &String, offset: usize) -> Option<usize>
fn next(s: &String, offset: usize) -> Option<usize>
Returns the index of the first boundary for which index > offset,
or None if no such boundary exists. Input and result are in base units.
fn can_fragment() -> bool
fn can_fragment() -> bool
Returns true if the measured units in this metric can span multiple
leaves. As an example, in a metric that measures lines in a rope, a
line may start in one leaf and end in another; however in a metric
measuring bytes, storage of a single byte cannot extend across leaves.
impl Copy for Utf16CodeUnitsMetric