Struct BaseMetric
pub struct BaseMetric(/* private fields */);Expand description
This metric let us walk utf8 text by code point.
BaseMetric implements the trait Metric. Both its measured unit and
its base unit are utf8 code unit.
Offsets that do not correspond to codepoint boundaries are invalid, and calling functions that assume valid offsets with invalid offets will panic in debug mode.
Boundary is atomic and determined by codepoint boundary. Atomicity is
implicit, because offsets between two utf8 code units that form a code
point is considered invalid. For example, if a string starts with a
0xC2 byte, then offset=1 is invalid.